@@ -42,35 +42,32 @@
 #include <QHeaderView>
 #include <QElapsedTimer>
 
-#include "playlist.h"
-#include "collectionlist.h"
-#include "dynamicplaylist.h"
-#include "upcomingplaylist.h"
-#include "historyplaylist.h"
-#include "viewmode.h"
-#include "searchplaylist.h"
-#include "treeviewitemplaylist.h"
 #include "actioncollection.h"
 #include "cache.h"
-#include "tagtransactionmanager.h"
-#include "playermanager.h"
+#include "collectionlist.h"
 #include "dbuscollectionproxy.h"
+#include "dynamicplaylist.h"
+#include "historyplaylist.h"
+#include "iconsupport.h"
 #include "juk_debug.h"
+#include "playermanager.h"
+#include "playlist.h"
+#include "searchplaylist.h"
+#include "tagtransactionmanager.h"
+#include "treeviewitemplaylist.h"
+#include "upcomingplaylist.h"
+#include "viewmode.h"
 
-using namespace ActionCollection;
+using namespace ActionCollection; // ""_act and others
+using namespace IconSupport;      // ""_icon
 
 ////////////////////////////////////////////////////////////////////////////////
 // PlaylistBox public methods
 ////////////////////////////////////////////////////////////////////////////////
 
-PlaylistBox::PlaylistBox(PlayerManager *player, QWidget *parent, QStackedWidget *playlistStack) :
-    QTreeWidget(parent),
-    PlaylistCollection(player, playlistStack),
-    m_viewModeIndex(0),
-    m_hasSelection(false),
-    m_doingMultiSelect(false),
-    m_dropItem(0),
-    m_showTimer(0)
+PlaylistBox::PlaylistBox(PlayerManager *player, QWidget *parent, QStackedWidget *playlistStack)
+  : QTreeWidget(parent)
+  , PlaylistCollection(player, playlistStack)
 {
     readConfig();
     setHeaderLabel("Playlists");
@@ -93,36 +90,36 @@ PlaylistBox::PlaylistBox(PlayerManager *player, QWidget *parent, QStackedWidget
 
     m_contextMenu = new QMenu(this);
 
-    m_contextMenu->addAction( action("file_new") );
-    m_contextMenu->addAction( action("renamePlaylist") );
-    m_contextMenu->addAction( action("editSearch") );
-    m_contextMenu->addAction( action("duplicatePlaylist") );
-    m_contextMenu->addAction( action("reloadPlaylist") );
-    m_contextMenu->addAction( action("deleteItemPlaylist") );
-    m_contextMenu->addAction( action("file_save") );
-    m_contextMenu->addAction( action("file_save_as") );
+    m_contextMenu->addAction(action("file_new"));
+    m_contextMenu->addAction(action("renamePlaylist"));
+    m_contextMenu->addAction(action("editSearch"));
+    m_contextMenu->addAction(action("duplicatePlaylist"));
+    m_contextMenu->addAction(action("reloadPlaylist"));
+    m_contextMenu->addAction(action("deleteItemPlaylist"));
+    m_contextMenu->addAction(action("file_save"));
+    m_contextMenu->addAction(action("file_save_as"));
 
     m_contextMenu->addSeparator();
 
     // add the view modes stuff
 
     KSelectAction *viewModeAction =
-        new KSelectAction( QIcon::fromTheme(QStringLiteral("view-choose")), i18n("View Modes"), ActionCollection::actions());
+        new KSelectAction("view-choose"_icon, i18n("View Modes"), ActionCollection::actions());
     ActionCollection::actions()->addAction("viewModeMenu", viewModeAction);
 
     ViewMode* viewmode = new ViewMode(this);
     m_viewModes.append(viewmode);
-    viewModeAction->addAction(QIcon::fromTheme(QStringLiteral("view-list-details")), viewmode->name());
+    viewModeAction->addAction("view-list-details"_icon, viewmode->name());
 
     CompactViewMode* compactviewmode = new CompactViewMode(this);
     m_viewModes.append(compactviewmode);
-    viewModeAction->addAction(QIcon::fromTheme(QStringLiteral("view-list-text")), compactviewmode->name());
+    viewModeAction->addAction("view-list-text"_icon, compactviewmode->name());
 
     // TODO: Fix the broken tree view mode
 #if 0
     TreeViewMode* treeviewmode = new TreeViewMode(this);
     m_viewModes.append(treeviewmode);
-    viewModeAction->addAction(QIcon::fromTheme(QStringLiteral("view-list-tree")), treeviewmode->name());
+    viewModeAction->addAction("view-list-tree"_icon, treeviewmode->name());
 #endif
 
     CollectionList::initialize(this);
@@ -136,17 +133,17 @@ PlaylistBox::PlaylistBox(PlayerManager *player, QWidget *parent, QStackedWidget
     connect(viewModeAction, &QAction::triggered,
             this, &PlaylistBox::slotSetViewMode);
 
-    connect(this, SIGNAL(itemSelectionChanged()),
-            this, SLOT(slotPlaylistChanged()));
+    connect(this, &PlaylistBox::itemSelectionChanged,
+            this, &PlaylistBox::slotPlaylistChanged);
 
-    connect(this, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)),
-            this, SLOT(slotDoubleClicked(QTreeWidgetItem*)));
+    connect(this, &PlaylistBox::itemDoubleClicked,
+            this, &PlaylistBox::slotDoubleClicked);
 
-    connect(this, SIGNAL(customContextMenuRequested(QPoint)),
-            this, SLOT(slotShowContextMenu(QPoint)));
+    connect(this, &PlaylistBox::customContextMenuRequested,
+            this, &PlaylistBox::slotShowContextMenu);
 
     connect(this, &PlaylistBox::signalPlayFile,
-            player, QOverload<const FileHandle &>::of(&PlayerManager::play));
+            player, qOverload<const FileHandle &>(&PlayerManager::play));
 
     const auto *tagManager = TagTransactionManager::instance();
     connect(tagManager, &TagTransactionManager::signalAboutToModifyTags,
@@ -156,25 +153,25 @@ PlaylistBox::PlaylistBox(PlayerManager *player, QWidget *parent, QStackedWidget
 
     setupUpcomingPlaylist();
 
-    connect(CollectionList::instance(), SIGNAL(signalNewTag(QString,uint)),
-            this, SLOT(slotAddItem(QString,uint)));
-    connect(CollectionList::instance(), SIGNAL(signalRemovedTag(QString,uint)),
-            this, SLOT(slotRemoveItem(QString,uint)));
-    connect(CollectionList::instance(), SIGNAL(cachedItemsLoaded()),
-            this, SLOT(slotLoadCachedPlaylists()));
-
-    m_savePlaylistTimer = 0;
+    const auto *collectionList = CollectionList::instance();
+    connect(collectionList, &CollectionList::signalNewTag,
+            this,           &PlaylistBox::slotAddItem);
+    connect(collectionList, &CollectionList::signalRemovedTag,
+            this,           &PlaylistBox::slotRemoveItem);
+    connect(collectionList, &CollectionList::cachedItemsLoaded,
+            this,           &PlaylistBox::slotLoadCachedPlaylists);
 
     KToggleAction *historyAction =
-        new KToggleAction(QIcon::fromTheme(QStringLiteral("view-history")), i18n("Show &History"), ActionCollection::actions());
+        new KToggleAction("view-history"_icon, i18n("Show &History"), ActionCollection::actions());
     ActionCollection::actions()->addAction("showHistory", historyAction);
-    connect(historyAction, SIGNAL(triggered(bool)),
-            this, SLOT(slotSetHistoryPlaylistEnabled(bool)));
+    connect(historyAction, &KToggleAction::triggered,
+            this,          &PlaylistBox::slotSetHistoryPlaylistEnabled);
 
     m_showTimer = new QTimer(this);
     m_showTimer->setSingleShot(true);
     m_showTimer->setInterval(500);
-    connect(m_showTimer, SIGNAL(timeout()), SLOT(slotShowDropTarget()));
+    connect(m_showTimer, &QTimer::timeout,
+            this,        &PlaylistBox::slotShowDropTarget);
 
     // hook up to the D-Bus
     (void) new DBusCollectionProxy(this, this);
@@ -380,7 +377,7 @@ void PlaylistBox::saveConfig()
 
 void PlaylistBox::remove()
 {
-    ItemList items = selectedBoxItems();
+    const ItemList items = selectedBoxItems();
 
     if(items.isEmpty())
         return;
@@ -388,16 +385,18 @@ void PlaylistBox::remove()
     QStringList files;
     QStringList names;
 
-    foreach(Item *item, items) {
-        if(item && item->playlist()) {
-            if (!item->playlist()->fileName().isEmpty() &&
-                QFileInfo::exists(item->playlist()->fileName()))
-            {
-                files.append(item->playlist()->fileName());
-            }
-
-            names.append(item->playlist()->name());
+    for(const auto &item : items) {
+        if(!item || !item->playlist()) {
+            qFatal("Ran into an empty item or item playlist when removing playlists!");
         }
+
+        if (!item->playlist()->fileName().isEmpty() &&
+            QFileInfo::exists(item->playlist()->fileName()))
+        {
+            files.append(item->playlist()->fileName());
+        }
+
+        names.append(item->playlist()->name());
     }
 
     if(!files.isEmpty()) {
@@ -406,9 +405,9 @@ void PlaylistBox::remove()
 
         if(remove == KMessageBox::Yes) {
             QStringList couldNotDelete;
-            for(QStringList::ConstIterator it = files.constBegin(); it != files.constEnd(); ++it) {
-                if(!QFile::remove(*it))
-                    couldNotDelete.append(*it);
+            for(const auto &playlistFile : qAsConst(files)) {
+                if(!QFile::remove(playlistFile))
+                    couldNotDelete.append(playlistFile);
             }
 
             if(!couldNotDelete.isEmpty())
@@ -418,59 +417,38 @@ void PlaylistBox::remove()
             return;
     }
     else if(items.count() > 1 || items.front()->playlist() != upcomingPlaylist()) {
-        if(KMessageBox::warningContinueCancelList(this,
-                                                  i18n("Are you sure you want to remove these "
-                                                       "playlists from your collection?"),
-                                                  names,
-                                                  i18n("Remove Items?"),
-                                                  KGuiItem(i18n("&Remove"), "user-trash")) == KMessageBox::Cancel)
+        if(KMessageBox::Cancel == KMessageBox::warningContinueCancelList(
+            this,
+            i18n("Are you sure you want to remove these "
+               "playlists from your collection?"),
+            names,
+            i18n("Remove Items?"),
+            KGuiItem(i18n("&Remove"), "user-trash")))
         {
             return;
         }
     }
 
-    PlaylistList removeQueue;
-
-    for(ItemList::ConstIterator it = items.constBegin(); it != items.constEnd(); ++it) {
-        if(*it != Item::collectionItem() &&
-           (*it)->playlist() &&
-           (!(*it)->playlist()->readOnly()))
+    for(const auto &item : items) {
+        if(item != Item::collectionItem() &&
+           !item->playlist()->readOnly())
         {
-            removeQueue.append((*it)->playlist());
+            if(item->playlist() != upcomingPlaylist())
+                delete item;
+            else {
+                action<KToggleAction>("showUpcoming")->setChecked(false);
+                setUpcomingPlaylistEnabled(false);
+            }
         }
     }
 
-    // FIXME removing items
-    /*if(items.back()->nextSibling() && static_cast<Item *>(items.back()->nextSibling())->playlist())
-        setSingleItem(items.back()->nextSibling());
-    else {
-        Item *i = static_cast<Item *>(items.front()->itemAbove());
-        while(i && !i->playlist())
-            i = static_cast<Item *>(i->itemAbove());
-
-        if(!i)
-            i = Item::collectionItem();
-
-        setSingleItem(i);
-    }*/
-
-    for(PlaylistList::ConstIterator it = removeQueue.constBegin(); it != removeQueue.constEnd(); ++it) {
-        if(*it != upcomingPlaylist())
-            delete *it;
-        else {
-            action<KToggleAction>("showUpcoming")->setChecked(false);
-            setUpcomingPlaylistEnabled(false);
-        }
-    }
+    setSingleItem(Item::collectionItem());
 }
 
 void PlaylistBox::setDynamicListsFrozen(bool frozen)
 {
-    for(QList<ViewMode *>::Iterator it = m_viewModes.begin();
-        it != m_viewModes.end();
-        ++it)
-    {
-        (*it)->setDynamicListsFrozen(frozen);
+    for(auto &playlistBoxItem : qAsConst(m_viewModes)) {
+        playlistBoxItem->setDynamicListsFrozen(frozen);
     }
 }
 
@@ -496,14 +474,16 @@ void PlaylistBox::slotShowDropTarget()
 
 void PlaylistBox::slotAddItem(const QString &tag, unsigned column)
 {
-    for(QList<ViewMode *>::Iterator it = m_viewModes.begin(); it != m_viewModes.end(); ++it)
-        (*it)->addItems(QStringList(tag), column);
+    for(auto &viewMode : qAsConst(m_viewModes)) {
+        viewMode->addItems(QStringList(tag), column);
+    }
 }
 
 void PlaylistBox::slotRemoveItem(const QString &tag, unsigned column)
 {
-    for(QList<ViewMode *>::Iterator it = m_viewModes.begin(); it != m_viewModes.end(); ++it)
-        (*it)->removeItem(tag, column);
+    for(auto &viewMode : qAsConst(m_viewModes)) {
+        viewMode->removeItem(tag, column);
+    }
 }
 
 void PlaylistBox::mousePressEvent(QMouseEvent *e)
@@ -538,13 +518,16 @@ void PlaylistBox::keyReleaseEvent(QKeyEvent *e)
     QTreeWidget::keyReleaseEvent(e);
 }
 
-PlaylistBox::ItemList PlaylistBox::selectedBoxItems() const
+PlaylistBox::ItemList PlaylistBox::selectedBoxItems()
 {
     ItemList l;
 
-    for(QTreeWidgetItemIterator it(const_cast<PlaylistBox *>(this),
-                                 QTreeWidgetItemIterator::Selected); *it; ++it)
+    for(QTreeWidgetItemIterator it(this, QTreeWidgetItemIterator::Selected)
+            ; *it
+            ; ++it)
+    {
         l.append(static_cast<Item *>(*it));
+    }
 
     return l;
 }
@@ -585,18 +568,18 @@ void PlaylistBox::slotPlaylistChanged()
     if(m_doingMultiSelect)
         return;
 
-    ItemList items = selectedBoxItems();
+    const ItemList items = selectedBoxItems();
     m_hasSelection = !items.isEmpty();
 
-    bool allowReload = false;
+    const bool allowReload = std::any_of(items.begin(), items.end(),
+        [](const auto &item) {
+            return item->playlist() && item->playlist()->canReload();
+        });
 
     PlaylistList playlists;
-    for(ItemList::ConstIterator it = items.constBegin(); it != items.constEnd(); ++it) {
-
-        Playlist *p = (*it)->playlist();
+    for(const auto &playlistBoxItem : items) {
+        auto p = playlistBoxItem->playlist();
         if(p) {
-            if(p->canReload())
-                allowReload = true;
             playlists.append(p);
         }
     }
@@ -628,10 +611,14 @@ void PlaylistBox::slotPlaylistChanged()
     if(singlePlaylist) {
         PlaylistCollection::raise(playlists.front());
 
-        if(playlists.front() == upcomingPlaylist())
+        if(playlists.front() == upcomingPlaylist()) {
             action("deleteItemPlaylist")->setText(i18n("Hid&e"));
-        else
+            action("deleteItemPlaylist")->setIcon("list-remove"_icon);
+        }
+        else {
             action("deleteItemPlaylist")->setText(i18n("R&emove"));
+            action("deleteItemPlaylist")->setIcon("user-trash"_icon);
+        }
     }
     else if(!playlists.isEmpty())
         createDynamicPlaylist(playlists);
@@ -696,20 +683,23 @@ void PlaylistBox::slotLoadCachedPlaylists()
     m_savePlaylistTimer = new QTimer(this);
     m_savePlaylistTimer->setInterval(3000); // 3 seconds with no change? -> commit
     m_savePlaylistTimer->setSingleShot(true);
-    connect(m_savePlaylistTimer, SIGNAL(timeout()), SLOT(slotSavePlaylists()));
+    connect(m_savePlaylistTimer, &QTimer::timeout,
+            this, &PlaylistBox::slotSavePlaylists);
 
     clearSelection();
     setCurrentItem(m_playlistDict[CollectionList::instance()]);
 
-    QTimer::singleShot(0, CollectionList::instance(), SLOT(slotCheckCache()));
-    QTimer::singleShot(0, object(), SLOT(slotScanFolders()));
+    QTimer::singleShot(0, this, [this]() {
+            CollectionList::instance()->slotCheckCache();
+            this->scanFolders();
+        });
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 // PlaylistBox::Item protected methods
 ////////////////////////////////////////////////////////////////////////////////
 
-PlaylistBox::Item *PlaylistBox::Item::m_collectionItem = 0;
+PlaylistBox::Item *PlaylistBox::Item::m_collectionItem = nullptr;
 
 PlaylistBox::Item::Item(PlaylistBox *listBox, const QString &icon, const QString &text, Playlist *l)
     : QObject(listBox), QTreeWidgetItem(listBox, QStringList(text)),
@@ -771,10 +761,12 @@ void PlaylistBox::Item::init()
     list->addNameToDict(itemText);
 
     if(m_playlist) {
-        connect(m_playlist, SIGNAL(signalNameChanged(QString)),
-                this, SLOT(slotSetName(QString)));
-        connect(m_playlist, SIGNAL(signalEnableDirWatch(bool)),
-                list->object(), SLOT(slotEnableDirWatch(bool)));
+        connect(m_playlist, &Playlist::signalNameChanged,
+                this,       &Item::slotSetName);
+        connect(m_playlist, &Playlist::signalEnableDirWatch,
+                this, [list](bool enable) {
+                    list->enableDirWatch(enable);
+                });
     }
 
     if(m_playlist == CollectionList::instance()) {
