@@ -41,29 +41,28 @@
 #include <sys/types.h>
 #include <dirent.h>
 
-#include "collectionlist.h"
 #include "actioncollection.h"
 #include "advancedsearchdialog.h"
+#include "collectionlist.h"
 #include "coverinfo.h"
-#include "searchplaylist.h"
+#include "directorylist.h"
 #include "folderplaylist.h"
 #include "historyplaylist.h"
-#include "upcomingplaylist.h"
-#include "directorylist.h"
+#include "iconsupport.h"
+#include "juk.h"
 #include "mediafiles.h"
 #include "playermanager.h"
-#include "juk.h"
+#include "searchplaylist.h"
+#include "upcomingplaylist.h"
 
 //Laurent: readd it
 //#include "collectionadaptor.h"
 
-using namespace ActionCollection;
-
 ////////////////////////////////////////////////////////////////////////////////
 // static methods
 ////////////////////////////////////////////////////////////////////////////////
 
-PlaylistCollection *PlaylistCollection::m_instance = 0;
+PlaylistCollection *PlaylistCollection::m_instance = nullptr;
 
 // Returns all folders in input list with their canonical path, if available, or
 // unchanged if not.
@@ -237,7 +236,8 @@ void PlaylistCollection::showMore(const QString &artist, const QString &album)
         components.append(c);
     }
 
-    auto search = new PlaylistSearch(playlists, components, PlaylistSearch::MatchAll, object());
+    auto search = new PlaylistSearch(playlists, components,
+            PlaylistSearch::MatchAll, collectionActions());
 
     if(m_showMorePlaylist)
         m_showMorePlaylist->setPlaylistSearch(search);
@@ -473,14 +473,25 @@ void PlaylistCollection::refreshItems()
     visiblePlaylist()->slotRefresh();
 }
 
+void PlaylistCollection::openItemDir()
+{
+    visiblePlaylist()->slotOpenItemDir();
+}
+
 void PlaylistCollection::renameItems()
 {
     visiblePlaylist()->slotRenameFile();
 }
 
-void PlaylistCollection::addCovers(bool fromFile)
+void PlaylistCollection::addLocalCover()
 {
-    visiblePlaylist()->slotAddCover(fromFile);
+    visiblePlaylist()->slotAddCover(true /* from file */);
+    playlistItemsChanged();
+}
+
+void PlaylistCollection::addInternetCover()
+{
+    visiblePlaylist()->slotAddCover(false /* not from file */);
     playlistItemsChanged();
 }
 
@@ -529,8 +540,8 @@ void PlaylistCollection::createSearchPlaylist()
 
     auto searchDialog = new AdvancedSearchDialog(
             name, *(new PlaylistSearch(JuK::JuKInstance())), JuK::JuKInstance());
-    QObject::connect(searchDialog, &QDialog::finished, object(), [searchDialog, this](int result)
-            {
+    QObject::connect(searchDialog, &QDialog::finished, collectionActions(),
+            [searchDialog, this](int result) {
                 if (result) {
                     raise(new SearchPlaylist(
                                 this,
@@ -583,21 +594,23 @@ HistoryPlaylist *PlaylistCollection::historyPlaylist() const
 
 void PlaylistCollection::setHistoryPlaylistEnabled(bool enable)
 {
-    if((enable && m_historyPlaylist) || (!enable && !m_historyPlaylist))
+    if(enable == static_cast<bool>(m_historyPlaylist)) {
         return;
+    }
 
     if(enable) {
-        action<KToggleAction>("showHistory")->setChecked(true);
+        ActionCollection::action<KToggleAction>("showHistory")->setChecked(true);
         m_historyPlaylist = new HistoryPlaylist(this);
         m_historyPlaylist->setName(i18n("History"));
         setupPlaylist(m_historyPlaylist, "view-history");
 
-        QObject::connect(m_playerManager, SIGNAL(signalItemChanged(FileHandle)),
-                historyPlaylist(), SLOT(appendProposedItem(FileHandle)));
+        QObject::connect(
+                m_playerManager,   &PlayerManager::signalItemChanged,
+                historyPlaylist(), &HistoryPlaylist::appendProposedItem);
     }
     else {
         delete m_historyPlaylist;
-        m_historyPlaylist = 0;
+        m_historyPlaylist = nullptr;
     }
 }
 
@@ -608,30 +621,25 @@ UpcomingPlaylist *PlaylistCollection::upcomingPlaylist() const
 
 void PlaylistCollection::setUpcomingPlaylistEnabled(bool enable)
 {
-    if((enable && m_upcomingPlaylist) || (!enable && !m_upcomingPlaylist))
+    if(enable == static_cast<bool>(m_upcomingPlaylist))
         return;
 
+    ActionCollection::action<KToggleAction>("showUpcoming")->setChecked(enable);
     if(enable) {
-        action<KToggleAction>("showUpcoming")->setChecked(true);
-        if(!m_upcomingPlaylist)
-            m_upcomingPlaylist = new UpcomingPlaylist(this);
-
+        m_upcomingPlaylist = new UpcomingPlaylist(this);
         setupPlaylist(m_upcomingPlaylist, "go-jump-today");
     }
     else {
-        action<KToggleAction>("showUpcoming")->setChecked(false);
-        bool raiseCollection = visiblePlaylist() == m_upcomingPlaylist;
-
-        if(raiseCollection) {
+        if(visiblePlaylist() == m_upcomingPlaylist) {
             raise(CollectionList::instance());
         }
 
         m_upcomingPlaylist->deleteLater();
-        m_upcomingPlaylist = 0;
+        m_upcomingPlaylist = nullptr;
     }
 }
 
-QObject *PlaylistCollection::object() const
+PlaylistCollection::ActionHandler *PlaylistCollection::collectionActions() const
 {
     return m_actionHandler;
 }
@@ -666,6 +674,12 @@ void PlaylistCollection::raise(Playlist *playlist)
     playlist->setSearchEnabled(m_searchEnabled);
     m_playlistStack->setCurrentWidget(playlist);
     clearShowMore(false);
+
+    const auto playingItem = Playlist::playingItem();
+    if(playingItem && visiblePlaylist() != playlist && playingItem->playlist() == playlist) {
+        playlist->scrollToItem(playingItem, QAbstractItemView::PositionAtCenter);
+    }
+
     playlistItemsChanged();
 }
 
@@ -688,7 +702,7 @@ void PlaylistCollection::setupPlaylist(Playlist *playlist, const QString &)
 
     m_playlistStack->addWidget(playlist);
     QObject::connect(playlist, SIGNAL(itemSelectionChanged()),
-                     object(), SIGNAL(signalSelectedItemsChanged()));
+                     collectionActions(), SIGNAL(signalSelectedItemsChanged()));
 }
 
 bool PlaylistCollection::importPlaylists() const
@@ -731,10 +745,10 @@ void PlaylistCollection::enableDirWatch(bool enable)
 {
     auto collection = CollectionList::instance();
 
-    m_dirLister.disconnect(object());
+    m_dirLister.disconnect(collectionActions());
     if(enable) {
         QObject::connect(&m_dirLister, &KDirLister::newItems,
-                object(), [this](const KFileItemList &items) {
+                collectionActions(), [this](const KFileItemList &items) {
                     this->newItems(items);
                 });
         QObject::connect(&m_dirLister, &KDirLister::refreshItems,
@@ -877,7 +891,7 @@ void PlaylistCollection::saveConfig()
 {
     KConfigGroup config(KSharedConfig::openConfig(), "Playlists");
     config.writeEntry("ImportPlaylists", m_importPlaylists);
-    config.writeEntry("showUpcoming", action("showUpcoming")->isChecked());
+    config.writeEntry("showUpcoming", ActionCollection::action("showUpcoming")->isChecked());
     config.writePathEntry("DirectoryList", m_folderList);
     config.writePathEntry("ExcludeDirectoryList", m_excludedFolderList);
 
@@ -888,101 +902,159 @@ void PlaylistCollection::saveConfig()
 // ActionHandler implementation
 ////////////////////////////////////////////////////////////////////////////////
 
-PlaylistCollection::ActionHandler::ActionHandler(PlaylistCollection *collection) :
-    QObject(nullptr),
-    m_collection(collection)
+PlaylistCollection::ActionHandler::ActionHandler(PlaylistCollection *collection)
+  : QObject(nullptr)
+  , m_collection(collection)
 {
-    setObjectName( QLatin1String("ActionHandler" ));
+    using namespace IconSupport; // ""_icon
+
+    setObjectName(QLatin1String("ActionHandler"));
 
     KActionMenu *menu;
+    KActionCollection *actionCollection = ActionCollection::actions();
 
     // "New" menu
 
-    menu = new KActionMenu(QIcon::fromTheme(QStringLiteral("document-new")), i18nc("new playlist", "&New"), actions());
-    actions()->addAction("file_new", menu);
+    menu = new KActionMenu("document-new"_icon, i18nc("new playlist", "&New"), this);
+    actionCollection->addAction("file_new", menu);
 
-    menu->addAction(createAction(i18n("&Empty Playlist..."), SLOT(slotCreatePlaylist()),
-                              "newPlaylist", "window-new", QKeySequence(Qt::CTRL + Qt::Key_N)));
-    menu->addAction(createAction(i18n("&Search Playlist..."), SLOT(slotCreateSearchPlaylist()),
-                              "newSearchPlaylist", "edit-find", QKeySequence(Qt::CTRL + Qt::Key_F)));
-    menu->addAction(createAction(i18n("Playlist From &Folder..."), SLOT(slotCreateFolderPlaylist()),
-                              "newDirectoryPlaylist", "document-open", QKeySequence(Qt::CTRL + Qt::Key_D)));
+    menu->addAction(createAction(i18n("&Empty Playlist..."),
+                qOverload<>(&PlaylistCollection::createPlaylist),
+                "newPlaylist", "window-new",
+                QKeySequence(Qt::CTRL + Qt::Key_N)));
+    menu->addAction(createAction(i18n("&Search Playlist..."),
+                &PlaylistCollection::createSearchPlaylist,
+                "newSearchPlaylist", "edit-find",
+                QKeySequence(Qt::CTRL + Qt::Key_F)));
+    menu->addAction(createAction(i18n("Playlist From &Folder..."),
+                &PlaylistCollection::createFolderPlaylist,
+                "newDirectoryPlaylist", "document-open",
+                QKeySequence(Qt::CTRL + Qt::Key_D)));
 
     // Guess tag info menu
 
 #if HAVE_TUNEPIMP
-    menu = new KActionMenu(i18n("&Guess Tag Information"), actions());
-    actions()->addAction("guessTag", menu);
+    menu = new KActionMenu(i18n("&Guess Tag Information"), actionCollection);
+    actionCollection->addAction("guessTag", menu);
 
-    menu->setIcon(QIcon::fromTheme("wizard"));
+    menu->setIcon("wizard"_icon);
 
-    menu->addAction(createAction(i18n("From &File Name"), SLOT(slotGuessTagFromFile()),
-                              "guessTagFile", "document-import", QKeySequence(Qt::CTRL + Qt::Key_G)));
-    menu->addAction(createAction(i18n("From &Internet"), SLOT(slotGuessTagFromInternet()),
-                              "guessTagInternet", "network-server", QKeySequence(Qt::CTRL + Qt::Key_I)));
+    menu->addAction(createAction(i18n("From &File Name"),
+                &PlaylistCollection::guessTagFromFile,
+                "guessTagFile", "document-import",
+                QKeySequence(Qt::CTRL + Qt::Key_G)));
+    menu->addAction(createAction(i18n("From &Internet"),
+                &PlaylistCollection::guessTagFromInternet,
+                "guessTagInternet", "network-server",
+                QKeySequence(Qt::CTRL + Qt::Key_I)));
 #else
-    createAction(i18n("Guess Tag Information From &File Name"), SLOT(slotGuessTagFromFile()),
-                 "guessTag", "document-import", QKeySequence(Qt::CTRL + Qt::Key_G));
+    createAction(i18n("Guess Tag Information From &File Name"),
+                &PlaylistCollection::guessTagFromFile,
+                "guessTag", "document-import",
+                QKeySequence(Qt::CTRL + Qt::Key_G));
 #endif
 
 
-    createAction(i18n("Play First Track"),SLOT(slotPlayFirst()),     "playFirst");
-    createAction(i18n("Play Next Album"), SLOT(slotPlayNextAlbum()), "forwardAlbum", "go-down-search");
+    createAction(i18n("Play First Track"), &PlaylistCollection::playFirst,
+            "playFirst");
+    createAction(i18n("Play Next Album"), &PlaylistCollection::playNextAlbum,
+            "forwardAlbum", "go-down-search");
 
-    KStandardAction::open(this, SLOT(slotOpen()), actions());
-    KStandardAction::save(this, SLOT(slotSave()), actions());
-    KStandardAction::saveAs(this, SLOT(slotSaveAs()), actions());
+    KStandardAction::open(this, SLOT(slotOpen()), actionCollection);
+    KStandardAction::save(this, SLOT(slotSave()), actionCollection);
+    KStandardAction::saveAs(this, SLOT(slotSaveAs()), actionCollection);
 
-    createAction(i18n("Manage &Folders..."),  SLOT(slotManageFolders()),    "openDirectory", "folder-new");
-    createAction(i18n("&Rename..."),      SLOT(slotRename()),       "renamePlaylist", "edit-rename");
+    createAction(i18n("Manage &Folders..."), &PlaylistCollection::addFolder,
+            "openDirectory", "folder-new");
+    createAction(i18n("&Rename..."), &PlaylistCollection::rename,
+            "renamePlaylist", "edit-rename");
     createAction(i18nc("verb, copy the playlist", "D&uplicate..."),
-                 SLOT(slotDuplicate()),    "duplicatePlaylist", "edit-copy");
-    createAction(i18n("R&emove"),         SLOT(slotRemove()),       "deleteItemPlaylist", "user-trash");
-    createAction(i18n("Reload"),          SLOT(slotReload()),       "reloadPlaylist", "view-refresh");
-    createAction(i18n("Edit Search..."),  SLOT(slotEditSearch()),   "editSearch");
+                 &PlaylistCollection::duplicate,
+                 "duplicatePlaylist", "edit-copy");
+    createAction(i18n("R&emove"), &PlaylistCollection::remove,
+            "deleteItemPlaylist", "user-trash");
+    createAction(i18n("Reload"), &PlaylistCollection::reload,
+            "reloadPlaylist", "view-refresh");
+    createAction(i18n("Edit Search..."), &PlaylistCollection::editSearch,
+            "editSearch");
 
-    createAction(i18n("&Delete"),         SLOT(slotRemoveItems()),  "removeItem", "edit-delete");
-    createAction(i18n("Refresh"),         SLOT(slotRefreshItems()), "refresh", "view-refresh");
-    createAction(i18n("&Rename File"),    SLOT(slotRenameItems()),  "renameFile", "document-save-as", QKeySequence(Qt::CTRL + Qt::Key_R));
+    createAction(i18n("&Delete"), &PlaylistCollection::removeItems,
+            "removeItem", "edit-delete");
+    createAction(i18n("Refresh"), &PlaylistCollection::refreshItems,
+            "refresh", "view-refresh");
+    createAction(i18n("Open Containing Folder"), &PlaylistCollection::openItemDir,
+            "openItemDir", "stock_folder");
+    createAction(i18n("&Rename File"), &PlaylistCollection::renameItems,
+            "renameFile", "document-save-as",
+            QKeySequence(Qt::CTRL + Qt::Key_R));
 
-    menu = new KActionMenu(i18n("Cover Manager"), actions());
-    actions()->addAction("coverManager", menu);
-    menu->setIcon(QIcon::fromTheme("image-x-generic"));
+    menu = new KActionMenu(i18n("Cover Manager"), actionCollection);
+    actionCollection->addAction("coverManager", menu);
+    menu->setIcon("image-x-generic"_icon);
     menu->addAction(createAction(i18n("&View Cover"),
-        SLOT(slotViewCovers()), "viewCover", "document-preview"));
+        &PlaylistCollection::viewCovers, "viewCover", "document-preview"));
     menu->addAction(createAction(i18n("Get Cover From &File..."),
-        SLOT(slotAddLocalCover()), "addCover", "document-import", QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_F)));
+        &PlaylistCollection::addLocalCover, "addCover", "document-import",
+        QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_F)));
     menu->addAction(createAction(i18n("Get Cover From &Internet..."),
-        SLOT(slotAddInternetCover()), "webImageCover", "network-server", QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_G)));
+        &PlaylistCollection::addInternetCover,
+        "webImageCover", "network-server",
+        QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_G)));
     menu->addAction(createAction(i18n("&Delete Cover"),
-        SLOT(slotRemoveCovers()), "removeCover", "edit-delete"));
+        &PlaylistCollection::removeCovers, "removeCover", "edit-delete"));
     menu->addAction(createAction(i18n("Show Cover &Manager"),
-        SLOT(slotShowCoverManager()), "showCoverManager"));
+        &PlaylistCollection::showCoverManager, "showCoverManager"));
 
-    KToggleAction *upcomingAction =
-        new KToggleAction(QIcon::fromTheme(QStringLiteral("go-jump-today")), i18n("Show &Play Queue"), actions());
-    actions()->addAction("showUpcoming", upcomingAction);
+    auto upcomingAction = new KToggleAction(
+            "go-jump-today"_icon, i18n("Show &Play Queue"), actionCollection);
+    actionCollection->addAction("showUpcoming", upcomingAction);
 
-    connect(upcomingAction, SIGNAL(triggered(bool)),
-            this, SLOT(slotSetUpcomingPlaylistEnabled(bool)));
+    connect(upcomingAction, &KToggleAction::triggered,
+            this, [this](bool enable) {
+                m_collection->setUpcomingPlaylistEnabled(enable);
+            });
 
     connect(m_collection->m_playerManager, &PlayerManager::signalStop,
             this, [this]() { m_collection->stop(); });
 }
 
-QAction *PlaylistCollection::ActionHandler::createAction(const QString &text,
-                                                         const char *slot,
-                                                         const char *name,
-                                                         const QString &icon,
-                                                         const QKeySequence &shortcut)
+//
+// Used with ActionHandler::createAction below to dispatch QAction::triggered(bool) to slots
+// that will actually use the bool parameter... or not, as the case may be
+//
+
+template<int k = 1>
+static void invokeSlot(PlaylistCollection *c, void (PlaylistCollection::*ptr)(bool), bool b)
 {
-    auto actionCollection = actions();
-    QAction *action = new QAction(text, actions());
+    (c->*ptr)(b);
+}
+
+template<int k = 0>
+static void invokeSlot(PlaylistCollection *c, void (PlaylistCollection::*ptr)(), bool)
+{
+    (c->*ptr)();
+}
+
+template<typename ... PMFArg>
+QAction *PlaylistCollection::ActionHandler::createAction(
+    const QString &text
+  , void (PlaylistCollection::*slot)(PMFArg...)
+  , const char *name
+  , const QString &icon
+  , const QKeySequence &shortcut
+  )
+{
+    KActionCollection *actionCollection = ActionCollection::actions();
+    QAction *action = new QAction(text, actionCollection);
 
     if(!icon.isEmpty()) {
         action->setIcon(QIcon::fromTheme(icon));
     }
-    connect(action, SIGNAL(triggered(bool)), slot);
+
+    QObject::connect(action, &QAction::triggered, this,
+            [this, slot](bool b) -> void {
+                invokeSlot<sizeof...(PMFArg)>(m_collection, slot, b);
+            });
 
     actionCollection->addAction(name, action);
 
