@@ -21,6 +21,8 @@
 #include "searchadaptor.h"
 #include "juk_debug.h"
 
+#include <utility>
+
 #include <KLocalizedString>
 
 #include <QAction>
@@ -60,6 +62,7 @@ SearchLine::SearchLine(QWidget *parent, bool simple)
     layout->addWidget(m_lineEdit);
     m_lineEdit->setClearButtonEnabled(true);
     m_lineEdit->installEventFilter(this);
+    setFocusProxy(m_lineEdit);
     connect(m_lineEdit, SIGNAL(textChanged(QString)),
             this, SIGNAL(signalQueryChanged()));
     connect(m_lineEdit, SIGNAL(returnPressed()),
@@ -135,11 +138,6 @@ void SearchLine::clear()
         m_lineEdit->clear();
 }
 
-void SearchLine::setFocus()
-{
-    m_lineEdit->setFocus();
-}
-
 bool SearchLine::eventFilter(QObject *watched, QEvent *e)
 {
     if(watched != m_lineEdit || e->type() != QEvent::KeyPress)
@@ -203,6 +201,7 @@ SearchWidget::SearchWidget(QWidget *parent)
     m_lineEdit->setPlaceholderText(i18n("Search..."));
 
     connect(m_lineEdit, SIGNAL(returnPressed()), this, SIGNAL(returnPressed()));
+    setFocusProxy(m_lineEdit);
 
     updateColumns();
 }
@@ -233,9 +232,17 @@ PlaylistSearch* SearchWidget::search(const PlaylistList &playlists) const
 {
     PlaylistSearch::ComponentList components;
     components.append(searchComponent());
-    return new PlaylistSearch(playlists, components);
+    return new PlaylistSearch(std::move(playlists), std::move(components));
 }
 
+PlaylistSearch* SearchWidget::search(Playlist *playlist) const
+{
+    PlaylistSearch::ComponentList components;
+    components.append(searchComponent());
+
+    PlaylistList playlists = (PlaylistList{} << playlist);
+    return new PlaylistSearch(std::move(playlists), std::move(components));
+}
 
 ////////////////////////////////////////////////////////////////////////////////
 // SearchWidget public slots
